SolverFor

Trait SolverFor 

pub trait SolverFor<M, F, J> {
    type Tangent;

    const SPARSE: bool;
}
A solver that can minimize a model, and the tangent it works from.

The family of the model, being carried by the energy and force types, keeps the implementations for one solver from overlapping.

Required Associated Constants

const SPARSE: bool

Whether the solver wants the sparse structure of the assembled tangent.

Required Associated Types

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<B, const D: usize> SolverFor<Model<B, D>, Quantity<Energy>, TensorVector<TensorRank1<D, Current, Force>>> for NewtonRaphson

Source

impl<B, const D: usize> SolverFor<Model<B, D>, Quantity<PowerTemperature>, TensorVector<Quantity<Power>>> for NewtonRaphson

Source

impl<B, const D: usize> SolverFor<Model<B, D>, TensorVector<Quantity<Power>>, TensorVector<QuantitySparseVec<PowerPerTemperature>>> for NewtonRaphson

Source

impl<B, const D: usize> SolverFor<Model<B, D>, TensorVector<TensorRank1<D, Current, Force>>, TensorVector<TensorRank2SparseVec<D, Current, Current, ForcePerLength>>> for NewtonRaphson
where B: ElasticElements<D>,

Source

impl<B> SolverFor<Model<B, 3>, Quantity<Energy>, TensorVector<TensorRank1<3, Current, Force>>> for NewtonRaphson<Feti>

Available on crate feature fem only.
Source

impl<B> SolverFor<Model<B, 3>, TensorVector<TensorRank1<3, Current, Force>>, TensorVector<TensorRank2SparseVec<3, Current, Current, ForcePerLength>>> for NewtonRaphson<Feti>

Available on crate feature fem only.